import React, { useState, useEffect } from 'react';
import Input from "@/Components/FormComponents/Input";
import InputLabel from "@/Components/FormComponents/InputLabel";
import TextArea from "@/Components/FormComponents/TextArea";
import { useForm, router } from '@inertiajs/react';
import Button from '@/Components/Buttons/Button';
import { toast } from 'react-hot-toast';
import DeleteButton from '@/Components/Buttons/DeleteButton';
import Select from '@/Components/FormComponents/Select';

export default function StageForm({ stage, exitActions, filters }) {
    const { data, setData, post, processing } = useForm({
        name: stage?.name,
        description: stage?.description || '',
        exit_action: stage?.exit_action,
        filter_id: stage?.filter_id || null,
        _method: 'PUT'
    });

    // Estado para controlar modal delete
    const [isModalDeleteOpen, setIsModalDeleteOpen] = useState(false);
    const handleModalDelete = () => { setIsModalDeleteOpen(true) };
    const handleCloseModalDelete = () => { setIsModalDeleteOpen(false) };

    const { post: deleteStagePost, processing: deleteStageProcessing } = useForm({ id: stage?.id, _method: 'DELETE' });

    const deleteStage = (e) => {
        e.preventDefault();
        deleteStagePost(route('stage.delete', stage?.id), {
            onSuccess: () => {
                handleCloseModalDelete();
                toast.success('Etapa excluída com sucesso!');
            },
            onError: () => { toast.error('Ocorreu um erro inesperado.') }
        });
    };

    const stageUpdate = (e) => {
        e.preventDefault();
        post(route('stage.update', stage?.id), {
            onSuccess: () => {
                toast.success('Etapa atualizada com sucesso!');
            },
            onError: (error) => {
                toast.error(error?.error || 'Ocorreu um erro inesperado.');
                router.get(route('sdr.settings.funnel.details', stage?.id));
            }
        });
    };

    useEffect(() => {
        if (stage?.id) {
            setData({
                name: stage?.name,
                description: stage?.description || '',
                exit_action: stage?.exit_action,
                filter_id: stage?.filter_id || null,
                _method: 'PUT'
            });
        }
    }, [stage?.id]);

    return (
        <form onSubmit={stageUpdate} className="h-full flex flex-col justify-between">
            <div>
                <div className='flex justify-end mb-3'>
                    <DeleteButton isOpen={isModalDeleteOpen} openModal={handleModalDelete} closeModal={handleCloseModalDelete} onDelete={deleteStage} disabled={deleteStageProcessing} />
                </div>

                <div className='mb-2'>
                    <InputLabel htmlFor={`name-` + stage?.id} value="Nome da etapa" required />

                    <Input
                        id={`name-` + stage?.id}
                        type="text"
                        name="name"
                        className="w-full"
                        autoComplete="off"
                        required
                        placeholder="Nome da etapa"
                        value={data.name}
                        onChange={(e) => setData("name", e.target.value)}
                    />
                </div>

                <div className='mb-1'>
                    <InputLabel htmlFor={`description-` + stage?.id} value="Descrição" />

                    <TextArea
                        id={`description-` + stage?.id}
                        name="description"
                        value={data.description}
                        rows="4"
                        autoComplete="off"
                        placeholder="Descrição"
                        onChange={(e) => setData("description", e.target.value)}
                    />
                </div>

                <div className='mb-3'>
                    <InputLabel htmlFor={`exit_action-` + stage?.id} value="Ação de saída da etapa" />
                    <Select
                        id={`exit_action-` + stage?.id}
                        name="exit_action"
                        value={data.exit_action}
                        onChange={(e) => setData("exit_action", e.target.value)}
                    >
                        {exitActions.map((exit, index) => (
                            <option key={index} value={exit.value}>{exit.label}</option>
                        ))}
                    </Select>
                </div>

                {data.exit_action === '1' && (
                    <div className='mb-3'>
                        <InputLabel htmlFor={`filter_id-` + stage?.id} value="Filtro padrão" required />
                        <Select
                            id={`filter_id-` + stage?.id}
                            name="filter_id"
                            value={data.filter_id}
                            required={data.exit_action === '1'}
                            onChange={(e) => setData("filter_id", e.target.value)}
                        >
                            <option value="">Selecione um filtro</option>
                            {filters.map((filter, index) => (
                                <option key={index} value={filter?.id}>{filter.name}</option>
                            ))}
                        </Select>
                    </div>
                )}
            </div>

            <Button className='w-full' disabled={processing}>Salvar</Button>
        </form>
    );
}